@@ -1,3 +1,4 @@
+import os
 import shutil
 import tempfile
 from datetime import datetime, timedelta
@@ -31,6 +32,7 @@ class ContainerFactory(metaclass=Singleton):
         key = source.full_path
 
         tmp_dir = tempfile.mkdtemp()
+        os.chmod(tmp_dir, 0o777)
         shutil.copy(source.full_path, tmp_dir)
         self._volume_dis[key] = tmp_dir
 
@@ -44,6 +46,7 @@ class ContainerFactory(metaclass=Singleton):
                 working_dir="/src",
                 volumes=volume_info,
                 detach=True,
+                entrypoint="",
             )
         return self._containers[key]
 
@@ -56,9 +59,7 @@ class ContainerFactory(metaclass=Singleton):
         :param parallel: whether image download is occurring in parallel
         :return: a docker image
         """
-        images = self._client.images.list(
-            name=f"{container_info.image}:{str(container_info.tag)}"
-        )
+        images = self._client.images.list(name=f"{container_info.image}:{container_info.tag!s}")
         if len(images) == 1:
             return images[0]
         if not quiet:
@@ -75,11 +76,7 @@ class ContainerFactory(metaclass=Singleton):
             stream=True,
             decode=True,
         ):
-            if (
-                not quiet
-                and not parallel
-                and datetime.now() - last_update > timedelta(seconds=5)
-            ):
+            if not quiet and not parallel and datetime.now() - last_update > timedelta(seconds=5):
                 print("... ", end="", flush=True)
                 last_update = datetime.now()
         if not quiet:
@@ -91,14 +88,25 @@ class ContainerFactory(metaclass=Singleton):
             else:
                 print("done", flush=True)
 
-        images = self._client.images.list(
-            name=f"{container_info.image}:{str(container_info.tag)}"
-        )
+        images = self._client.images.list(name=f"{container_info.image}:{container_info.tag!s}")
         if len(images) == 1:
             return images[0]
 
         return None
 
+    def remove_image(self, container_info):
+        """
+        Remove a docker image
+
+        :param container_info: metadata about the image to remove
+        """
+
+        image_name = f"{container_info.image}:{container_info.tag!s}"
+        images = self._client.images.list(name=f"{container_info.image}:{container_info.tag!s}")
+        if len(images) == 1:
+            print(f"Removing {image_name}", flush=True)
+            self._client.images.remove(image=image_name, force=True)
+
     def cleanup(self, source):
         """
         Cleanup docker container and temporary folder. Also remove both from their
